@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::CompletionDriver::Turtles;
 # ABSTRACT: Complete Turtles-based commands
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003029';
 
 use Devel::REPL::Plugin;
 use Devel::REPL::Plugin::Completion;    # die early if cannot load
@@ -54,13 +54,21 @@ Devel::REPL::Plugin::CompletionDriver::Turtles - Complete Turtles-based commands
 
 =head1 VERSION
 
-version 1.003027
+version 1.003029
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
 
 =head1 AUTHOR
 
 Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
 
